@@ -1,6 +1,7 @@
 """ This module stores all the classification functions """
 
 import weaviate
+import random
 
 from weaviate_etl.utilities import get_weaviate_client
 from weaviate_etl.utilities import get_maxbatch
@@ -150,11 +151,11 @@ class Classification:
         """
 
         percentage = get_validation_percentage(self.classification)
-        random = get_random_selection(self.classification)
+        ransel = get_random_selection(self.classification)
         maxbatch = get_maxbatch(self.instance)
 
         if datapoints is not None:
-            size = calculate_size_training_set(datapoints, maxbatch, percentage, random)
+            size = calculate_size_training_set(datapoints, maxbatch, percentage, ransel)
 
             count = total = 0
             for point in datapoints:
@@ -321,6 +322,6 @@ class Classification:
             raise NoClassificationSet()
 
         if datapoints is None:
-            execute_classification(self.client, self.classification)
+            execute_classification(self.instance, self.client, self.classification)
         else:
             import_and_classify(self.instance, self.model, self.classification, datapoints)
